﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Threading.Tasks;
using FGCS.Core.Models;
using FGCS.Core.ViewModels;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;

namespace FGCS.Core.Controllers
{
    public class MerchantController : ValuesController
    {
        #region 商品规格字典数据
        /// <summary>
        /// 商品规格字典数据
        /// </summary>
        /// <returns></returns>
        public List<CommoditySpecificationDictionary> GetCommoditySpecificationDictionaries()
        {
            return to.CommoditySpecificationDictionary.Where(w => w.CdId == null).ToList();
        }
        #endregion

        #region 字典数据 经营类型
        /// <summary>
        /// 字典数据 经营类型
        /// </summary>
        /// <returns></returns>
        public List<Dictionary> GetDictionaries()
        {
            List<Dictionary> dictionaries = new List<Dictionary>();
            return to.Dictionary.Where(w => w.DType.Equals("主营类型")).ToList();
        }
        #endregion

        #region 添加字典数据 商品属性
        /// <summary>
        /// 添加字典数据 商品属性
        /// </summary>
        /// <param name="dic"></param>
        /// <returns></returns>
        [HttpPost]
        public List<AttributeVM> AddAttributeVM([FromBody]Dictionary dic)
        {
            Dictionary d = new Dictionary();
            d.CdId = dic.CdId;
            d.DType = dic.DType;
            d.DTypeDetailed = dic.DTypeDetailed;
            d.DText = dic.DText;
            d.DState = dic.DState;
            d.MuId = dic.MuId;
            d.OId = dic.OId;
            to.Entry(d).State = EntityState.Added;
            to.SaveChanges();
            return GetCommodityDictionaries(Convert.ToInt32(dic.CdId));
        }
        #endregion

        #region 删除商品属性
        /// <summary>
        /// 删除商品属性
        /// </summary>
        /// <param name="delete">属性对象</param>
        /// <returns></returns>
        [HttpPost]
        public List<AttributeVM> DeleteAttributeVM([FromBody]DeleteSpecificationListVM delete)
        {
            string sql = "delete from Dictionary where D_Id = " + delete.id + "";
            TOHepler.ExecuteNonQuery(sql);
            return GetCommodityDictionaries(Convert.ToInt32(delete.name));
        }
        #endregion

        #region 删除字典所属类型所有属性
        /// <summary>
        /// 删除字典所属类型所有属性
        /// </summary>
        /// <param name="delete">属性对象</param>
        /// <returns></returns>
        [HttpPost]
        public List<AttributeVM> DeleteAttributeVMList([FromBody]DeleteSpecificationListVM delete)
        {
            string sql = "delete from Dictionary where D_Type ='" + delete.name + "' and CD_Id = " + delete.id + "";
            TOHepler.ExecuteNonQuery(sql);
            return GetCommodityDictionaries(Convert.ToInt32(delete.id));
        }
        #endregion

        #region 字典数据 商品属性
        /// <summary>
        /// 字典数据 商品属性
        /// </summary>
        /// <param name="id">商品编号</param>
        /// <returns></returns>
        [HttpGet("{id}")]
        public List<AttributeVM> GetCommodityDictionaries(int id)
        {
            List<AttributeVM> attributes = new List<AttributeVM>();
            foreach (var i in to.Dictionary.Where(w => w.DText.Equals("商品") && w.CdId == id))
            {
                AttributeVM vM = new AttributeVM();
                if (!attributes.Any(a => a.name == i.DType))
                {
                    vM.id = i.DId;
                    vM.name = i.DType;
                    foreach (var l in to.Dictionary.Where(w => w.DText.Equals("商品") && w.CdId == id && w.DTypeDetailed != ""))
                    {
                        if (i.DType.Equals(l.DType))
                        {
                            AttributeListVM at = new AttributeListVM();
                            at.DId = l.DId;
                            at.DState = l.DState;
                            at.DType = l.DType;
                            at.DTypeDetailed = l.DTypeDetailed;
                            at.DState = l.DState;
                            vM.attributeListVMs.Add(at);
                        }
                    }
                    attributes.Add(vM);
                }
            }
            return attributes;
        }
        #endregion

        #region 订单绑定
        /// <summary>
        /// 订单绑定
        /// </summary>
        /// <param name="id">商家编号</param>
        /// <returns></returns>
        [HttpPost]
        public List<OrderVM> GetOrders([FromBody]DeleteSpecificationListVM delete)
        {
            string sql = "";
            List<OrderVM> vm = new List<OrderVM>();
            if (delete.name != null && delete.name != "1" && delete.name != "")
            {
                sql = @"select o.*,u.U_Name, m.M_Name,d.D_TypeDetailed from [Order] as o
inner join [User] as u on u.U_Id = o.U_Id
inner join Merchant as m on o.MU_Id = m.MU_Id
inner join Dictionary as d on o.O_Id  = d.O_Id
where o.MU_Id = " + delete.id + " and convert(varchar,o.O_Register,120) like '" + delete.name + "%'";
            }
            else
            {
                sql = @"select o.*,u.U_Name, m.M_Name,d.D_TypeDetailed from [Order] as o
inner join [User] as u on u.U_Id = o.U_Id
inner join Merchant as m on o.MU_Id = m.MU_Id
inner join Dictionary as d on o.O_Id  = d.O_Id
where o.MU_Id = " + delete.id + "";
            }
            DataTable table = TOHepler.GetData(sql);
            foreach (DataRow i in table.Rows)
            {
                vm.Add(new OrderVM()
                {
                    OId = Convert.ToInt32(i.ItemArray[0]),
                    UId = Convert.ToInt32(i.ItemArray[1]),
                    UName = Convert.ToString(i.ItemArray[7]),
                    MName = Convert.ToString(i.ItemArray[8]),
                    DTypeDetailed = Convert.ToString(i.ItemArray[9]),
                    MUId = Convert.ToInt32(i.ItemArray[2]),
                    OText = Convert.ToString(i["O_Text"]),
                    OAddresss = Convert.ToString(i["O_Addresss"]),
                    OPrice = Convert.ToDecimal(i.ItemArray[6]),
                    ORegister = i.ItemArray[5].ToString().Substring(0, 16),
                });
            }
            return vm.OrderByDescending(o => o.OId).ToList();
        }
        #endregion

        #region 登录验证方法
        /// <summary>
        /// 登录验证方法
        /// </summary>
        /// <param name="l">账户密码对象</param>
        /// <returns></returns>
        [HttpPost]
        public User GetUserVMLogin([FromBody]Login l)
        {
            User user = to.User.FirstOrDefault(f => f.UAccount.Equals(l.Account) && f.UPassword.Equals(l.Password));
            return user == null ? null : user;
        }
        #endregion

        #region 修改店铺 店铺信息
        /// <summary>
        /// 修改店铺 店铺信息
        /// </summary>
        /// <param name="id">店铺id</param>
        /// <param name="mer">新数据</param>
        /// <returns></returns>
        [HttpPut("{id}")]
        public DataRow UpdateMerchant(int id, [FromBody]Merchant mer)
        {
            Merchant me = to.Merchant.FirstOrDefault(f => f.MuId == id);
            me.MName = mer.MName;
            me.MRegisterDate = mer.MRegisterDate;
            me.MPhone = mer.MPhone;
            me.MAddress = mer.MAddress;
            me.MDetailsAddress = mer.MDetailsAddress;
            me.MPicture = mer.MPicture;
            me.MText = mer.MText;
            me.MState = mer.MState;
            to.Entry(me).State = EntityState.Modified;
            to.SaveChanges();
            string sql = @"select * from Merchant where MU_Id = '" + id + "'";
            DataTable table = TOHepler.GetData(sql);
            DataRow data = table.Rows[0];
            return data;
        }
        #endregion

        #region 添加店铺经营类型
        /// <summary>
        /// 添加店铺经营类型
        /// </summary>
        /// <param name="delete"></param>
        [HttpPost]
        public void UpdateAddDictionary([FromBody]DeleteSpecificationListVM delete)
        {
            Dictionary dic = to.Dictionary.FirstOrDefault(f => f.MuId == delete.id && f.DType.Equals("主营类型"));
            if (dic == null)
            {
                Dictionary d = new Dictionary();
                d.CdId = null;
                d.DType = "主营类型";
                d.DTypeDetailed = delete.name;
                d.DText = "店铺";
                d.DState = true;
                d.MuId = delete.id;
                d.OId = null;
                to.Entry(d).State = EntityState.Added;
                to.SaveChanges();
            }
            else
            {
                dic.CdId = null;
                dic.DType = "主营类型";
                dic.DTypeDetailed = delete.name;
                dic.DText = "店铺";
                dic.DState = true;
                dic.MuId = delete.id;
                dic.OId = null;
                to.Entry(dic).State = EntityState.Modified;
                to.SaveChanges();
            }
        }
        #endregion

        #region 根据用户Id绑定所属店铺
        /// <summary>
        /// 根据用户Id绑定所属店铺
        /// </summary>
        /// <param name="id">用户</param>
        /// <returns></returns>
        [HttpGet("{id}")]
        public DataRow GetMerchant(int id)
        {
            string sql = @"select * from Merchant where MU_Id = '" + id + "'";
            DataTable table = TOHepler.GetData(sql);
            DataRow data = table.Rows[0];
            return data;
        }
        #endregion

        #region 根据店铺Id绑定商品
        /// <summary>
        /// 根据店铺Id绑定商品
        /// </summary>
        /// <param name="id">店铺</param>
        /// <returns></returns>
        [HttpGet("{id}")]
        public List<CommodityType> GetCommodityType(int id)
        {
            List<CommodityType> type = to.CommodityType.Where(w => w.MuId == id).ToList();
            return type;
        }
        #endregion

        #region 添加商品分类
        /// <summary>
        /// 添加商品分类
        /// </summary>
        /// <param name="c">商品对象</param>
        /// <returns></returns>
        [HttpPost]
        public List<CommodityType> AddCommodityType([FromBody]CommodityType c)
        {
            CommodityType commodity = c;
            to.Entry(commodity).State = EntityState.Added;
            to.SaveChanges();
            return GetCommodityType(c.MuId);
        }
        #endregion

        #region 删除商品分类
        /// <summary>
        /// 删除商品分类
        /// </summary>
        /// <param name="d">商品</param>
        /// <returns></returns>
        [HttpPost]
        public List<CommodityType> DeleteCommodityType([FromBody]DeleteSpecificationListVM d)
        {
            string sql = @"delete from CommodityType where CT_Id = " + d.id + "" +
                "update CommodityDetails set CT_Id = null where CT_Id = " + d.id + "";
            TOHepler.ExecuteNonQuery(sql);
            return GetCommodityType(Convert.ToInt32(d.name));
        }
        #endregion

        #region 删除商品详情
        /// <summary>
        /// 删除商品详情
        /// </summary>
        /// <param name="delete"></param>
        /// <returns></returns>
        [HttpPost]
        public List<CommodityDetails> DeleteCommodities([FromBody]DeleteSpecificationListVM delete)
        {
            string sql = @"delete from CommodityDetails where CD_Id = " + delete.id + " delete from Dictionary where CD_Id =" + delete.id + "  delete from CommoditySpecificationDictionary where CD_Id =" + delete.id + "";
            TOHepler.ExecuteNonQuery(sql);
            return to.CommodityDetails.Where(w => w.MuId == Convert.ToInt32(delete.name)).ToList();
        }
        #endregion

        #region 根据店铺绑定商品详情
        /// <summary>
        /// 根据店铺绑定商品详情
        /// </summary>
        /// <param name="id">店铺</param>
        /// <returns></returns>
        [HttpGet("{id}")]
        public List<CommodityDetails> GetCommodityDetails(int id)
        {
            List<CommodityDetails> commodities = to.CommodityDetails.Where(w => w.MuId == id).ToList();
            return commodities;
        }
        #endregion

        #region 获取商品详情
        /// <summary>
        /// 获取商品详情
        /// </summary>
        /// <param name="id">商品</param>
        /// <returns>商品详情</returns>
        [HttpGet("{id}")]
        public CommodityDetails ShowCommodityDetails(int id)
        {
            CommodityDetails commodities = to.CommodityDetails.FirstOrDefault(f => f.CdId == id);
            return commodities;
        }
        #endregion

        #region 添加商品详情
        /// <summary>
        /// 添加商品详情
        /// </summary>
        /// <param name="c"></param>
        /// <returns></returns>
        [HttpPost]
        public CommodityDetails AddCommodityDetails([FromBody]CommodityDetails c)
        {
            try
            {
                CommodityDetails commodity = new CommodityDetails();
                commodity.CdName = c.CdName;
                commodity.CtId = c.CtId;
                commodity.MuId = c.MuId;
                commodity.CdPrice = c.CdPrice;
                commodity.CdPicture = c.CdPicture;
                commodity.CdDescribe = c.CdDescribe;
                commodity.CdSum = c.CdSum;
                commodity.CdState = c.CdState;
                commodity.CdRecommend = c.CdRecommend;
                to.Entry(commodity).State = EntityState.Added;
                to.SaveChanges();
                return commodity;
            }
            catch (Exception)
            {
                return null;
            }
        }
        #endregion

        #region 添加商品规格
        /// <summary>
        /// 添加商品规格
        /// </summary>
        /// <param name="csd"></param>
        /// <returns></returns>
        [HttpPost]
        public List<SpecificationVM> AddCommoditySpecificationDictionary([FromBody]CommoditySpecificationDictionary csd)
        {
            if (csd.CsdType == null || csd.CsdType == "")
            {
                return CSD(Convert.ToInt32(csd.CdId));
            }
            CommoditySpecificationDictionary com = new CommoditySpecificationDictionary();
            try
            {
                com.CdId = csd.CdId;
                com.CsdType = csd.CsdType;
                com.CsdTypeName = csd.CsdTypeName;
                com.CsdTypePrice = csd.CsdTypePrice;
                com.CsdTypeSum = csd.CsdTypeSum;
                to.Entry(com).State = EntityState.Added;
                to.SaveChanges();
                return CSD(Convert.ToInt32(csd.CdId));
            }
            catch (Exception)
            {
                return CSD(Convert.ToInt32(csd.CdId));
            }
        }
        #endregion

        #region 批量添加商品规格
        /// <summary>
        /// 批量添加商品规格
        /// </summary>
        /// <param name="csd"></param>
        /// <returns></returns>
        [HttpPut("{id}")]
        public List<SpecificationVM> AddCommoditySpecificationDictionaryList(int id, [FromBody]List<CommoditySpecificationDictionary> csd)
        {
            try
            {
                foreach (var i in csd)
                {
                    CommoditySpecificationDictionary com = new CommoditySpecificationDictionary();
                    com.CdId = id;
                    com.CsdType = i.CsdType;
                    com.CsdTypeName = i.CsdTypeName;
                    com.CsdTypePrice = i.CsdTypePrice;
                    com.CsdTypeSum = i.CsdTypeSum;
                    to.Entry(com).State = EntityState.Added;
                    to.SaveChanges();
                }
                return CSD(Convert.ToInt32(id));
            }
            catch (Exception)
            {
                return CSD(Convert.ToInt32(id));
            }
        }
        #endregion

        #region 删除商品规格
        /// <summary>
        /// 删除商品规格
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpDelete("{id}")]
        public List<SpecificationVM> DeleteCommoditySpecificationDictionary(int id)
        {
            int cdid = 0;
            try
            {
                CommoditySpecificationDictionary commodity = to.CommoditySpecificationDictionary.FirstOrDefault(f => f.CsdId == id);
                to.Entry(commodity).State = EntityState.Deleted;
                to.SaveChanges();
                cdid = Convert.ToInt32(commodity.CdId);
                return CSD(cdid);
            }
            catch (Exception)
            {
                return CSD(cdid);
            }
        }
        #endregion

        #region 删除商品该类型所有规格
        /// <summary>
        /// 删除商品该类型所有规格
        /// </summary>
        /// <param name="com"></param>
        /// <returns></returns>
        [HttpPost]
        public List<SpecificationVM> DeleteSpecificationList([FromBody]DeleteSpecificationListVM delete)
        {
            string sql = @"delete  from CommoditySpecificationDictionary
where CD_Id = " + delete.id + " and CSD_Type = '" + delete.name + "'";
            TOHepler.ExecuteNonQuery(sql);
            return CSD(delete.id);

        }
        #endregion

        #region 修改商品详情
        /// <summary>
        /// 修改商品详情
        /// </summary>
        /// <param name="id">商品编号</param>
        /// <param name="c">更新商品数据</param>
        /// <returns>商品详情</returns>
        [HttpPut("{id}")]
        public CommodityDetails UpdateCommodityDetails(int id, [FromBody]CommodityDetails c)
        {
            try
            {
                CommodityDetails commodity = to.CommodityDetails.FirstOrDefault(F => F.CdId == id);
                commodity.CdName = c.CdName;
                commodity.CtId = c.CtId;
                commodity.MuId = c.MuId;
                commodity.CdPrice = c.CdPrice;
                commodity.CdPicture = c.CdPicture;
                commodity.CdDescribe = c.CdDescribe;
                commodity.CdSum = c.CdSum;
                commodity.CdState = c.CdState;
                commodity.CdRecommend = c.CdRecommend;
                to.Entry(commodity).State = EntityState.Modified;
                to.SaveChanges();
                return ShowCommodityDetails(id);
            }
            catch (Exception)
            {
                return ShowCommodityDetails(id);
            }
        }
        #endregion

        #region 修改商品规格
        /// <summary>
        /// 修改商品规格
        /// </summary>
        /// <param name="id">商品编号</param>
        /// <param name="csd">新商品规格</param>
        /// <returns></returns>
        [HttpPut("{id}")]
        public List<SpecificationVM> UpdateCommoditySpecificationDictionary(int id, [FromBody]List<CommoditySpecificationDictionary> csd)
        {
            List<CommoditySpecificationDictionary> commodity = to.CommoditySpecificationDictionary.Where(w => w.CdId != null && w.CdId == id).ToList();
            try
            {
                foreach (var i in csd)
                {
                    CommoditySpecificationDictionary com = commodity.FirstOrDefault(f => f.CsdId == i.CsdId);
                    com.CdId = i.CdId;
                    com.CsdType = i.CsdType;
                    com.CsdTypeName = i.CsdTypeName;
                    com.CsdTypePrice = i.CsdTypePrice;
                    com.CsdTypeSum = i.CsdTypeSum;
                    to.Entry(com).State = EntityState.Modified;
                    to.SaveChanges();

                }
                return CSD(Convert.ToInt32(id));
            }
            catch (Exception)
            {
                return CSD(Convert.ToInt32(id));
            }
        }
        #endregion

        #region 修改商品分类
        /// <summary>
        /// 修改商品分类
        /// </summary>
        /// <param name="id">商品id</param>
        /// <param name="c">商品更新后数据</param>
        /// <returns></returns>
        [HttpPut("{id}")]
        public List<CommodityType> UpdateCommodityType(int id, [FromBody]CommodityType c)
        {
            CommodityType commodity = to.CommodityType.FirstOrDefault(f => f.CtId == id);
            commodity.CtId = c.CtId;
            commodity.CtName = c.CtName;
            commodity.MuId = c.MuId;
            to.Entry(commodity).State = EntityState.Modified;
            to.SaveChanges();
            return GetCommodityType(c.MuId);
        }
        #endregion

        #region 绑定商品所属规格
        /// <summary>
        /// 绑定商品所属规格
        /// </summary>
        /// <param name="id">商品</param>
        /// <returns></returns>
        [HttpGet("{id}")]
        public List<SpecificationVM> CSD(int id)
        {
            List<SpecificationVM> d = new List<SpecificationVM>();
            List<CommoditySpecificationDictionary> dictionaries = to.CommoditySpecificationDictionary.Where(w => w.CdId != null).ToList();
            foreach (CommoditySpecificationDictionary i in dictionaries.Where(w => w.CdId == id).ToList())
            {
                SpecificationVM spe = new SpecificationVM();
                if (!d.Any(a => a.name == i.CsdType))
                {
                    spe.id = i.CsdId;
                    spe.name = i.CsdType;
                    foreach (CommoditySpecificationDictionary l in dictionaries.Where(w => w.CdId == id).ToList())
                    {
                        if (i.CsdType.Equals(l.CsdType) && l.CsdTypeName != null)
                        {
                            ComSpecificationVM com = new ComSpecificationVM();
                            com.CsdType = l.CsdType;
                            com.CsdId = l.CsdId;
                            com.CdId = l.CdId;
                            com.CsdTypeName = l.CsdTypeName;
                            com.CsdTypePrice = l.CsdTypePrice;
                            com.CsdTypeSum = l.CsdTypeSum;
                            spe.comSpecifications.Add(com);
                        }
                    }
                    d.Add(spe);
                }
            }
            return d;
        }
        #endregion
    }
}