﻿using System;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata;

namespace FGCS.Core.Models
{
    public partial class TakeOutContext : DbContext
    {
        public virtual DbSet<CommodityDetails> CommodityDetails { get; set; }
        public virtual DbSet<CommoditySpecificationDictionary> CommoditySpecificationDictionary { get; set; }
        public virtual DbSet<CommodityType> CommodityType { get; set; }
        public virtual DbSet<Dictionary> Dictionary { get; set; }
        public virtual DbSet<Merchant> Merchant { get; set; }
        public virtual DbSet<Order> Order { get; set; }
        public virtual DbSet<OrderDetails> OrderDetails { get; set; }
        public virtual DbSet<ShoppingTrolley> ShoppingTrolley { get; set; }
        public virtual DbSet<Uaddress> Uaddress { get; set; }
        public virtual DbSet<User> User { get; set; }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            if (!optionsBuilder.IsConfigured)
            {
#warning To protect potentially sensitive information in your connection string, you should move it out of source code. See http://go.microsoft.com/fwlink/?LinkId=723263 for guidance on storing connection strings.
                optionsBuilder.UseSqlServer(@"Server=.;database=TakeOut;uid=sa;pwd=sa");
            }
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.Entity<CommodityDetails>(entity =>
            {
                entity.HasKey(e => e.CdId);

                entity.Property(e => e.CdId).HasColumnName("CD_Id");

                entity.Property(e => e.CdDescribe)
                    .HasColumnName("CD_Describe")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.CdName)
                    .IsRequired()
                    .HasColumnName("CD_Name")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.CdPicture)
                    .HasColumnName("CD_Picture")
                    .HasMaxLength(200)
                    .IsUnicode(false);

                entity.Property(e => e.CdPrice)
                    .HasColumnName("CD_Price")
                    .HasColumnType("money");

                entity.Property(e => e.CdRecommend).HasColumnName("CD_Recommend");

                entity.Property(e => e.CdState).HasColumnName("CD_State");

                entity.Property(e => e.CdSum).HasColumnName("CD_Sum");

                entity.Property(e => e.CtId).HasColumnName("CT_Id");

                entity.Property(e => e.MuId).HasColumnName("MU_Id");

                entity.HasOne(d => d.Mu)
                    .WithMany(p => p.CommodityDetails)
                    .HasForeignKey(d => d.MuId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__Commodity__MU_Id__1B0907CE");
            });

            modelBuilder.Entity<CommoditySpecificationDictionary>(entity =>
            {
                entity.HasKey(e => e.CsdId);

                entity.Property(e => e.CsdId).HasColumnName("CSD_Id");

                entity.Property(e => e.CdId).HasColumnName("CD_Id");

                entity.Property(e => e.CsdType)
                    .HasColumnName("CSD_Type")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.CsdTypeName)
                    .HasColumnName("CSD_TypeName")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.CsdTypePrice)
                    .HasColumnName("CSD_TypePrice")
                    .HasColumnType("money");

                entity.Property(e => e.CsdTypeSum).HasColumnName("CSD_TypeSum");
            });

            modelBuilder.Entity<CommodityType>(entity =>
            {
                entity.HasKey(e => e.CtId);

                entity.Property(e => e.CtId).HasColumnName("CT_Id");

                entity.Property(e => e.CtName)
                    .IsRequired()
                    .HasColumnName("CT_Name")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.MuId).HasColumnName("MU_Id");

                entity.HasOne(d => d.Mu)
                    .WithMany(p => p.CommodityType)
                    .HasForeignKey(d => d.MuId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__Commodity__MU_Id__182C9B23");
            });

            modelBuilder.Entity<Dictionary>(entity =>
            {
                entity.HasKey(e => e.DId);

                entity.Property(e => e.DId).HasColumnName("D_Id");

                entity.Property(e => e.CdId).HasColumnName("CD_Id");

                entity.Property(e => e.DState).HasColumnName("D_State");

                entity.Property(e => e.DText)
                    .HasColumnName("D_Text")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.DType)
                    .IsRequired()
                    .HasColumnName("D_Type")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.DTypeDetailed)
                    .IsRequired()
                    .HasColumnName("D_TypeDetailed")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.MuId).HasColumnName("MU_Id");

                entity.Property(e => e.OId).HasColumnName("O_Id");

                entity.HasOne(d => d.Mu)
                    .WithMany(p => p.Dictionary)
                    .HasForeignKey(d => d.MuId)
                    .HasConstraintName("FK__Dictionar__MU_Id__29572725");

                entity.HasOne(d => d.O)
                    .WithMany(p => p.Dictionary)
                    .HasForeignKey(d => d.OId)
                    .HasConstraintName("FK__Dictionary__O_Id__2A4B4B5E");
            });

            modelBuilder.Entity<Merchant>(entity =>
            {
                entity.HasKey(e => e.MuId);

                entity.Property(e => e.MuId)
                    .HasColumnName("MU_Id")
                    .ValueGeneratedNever();

                entity.Property(e => e.MAddress)
                    .HasColumnName("M_Address")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.MDetailsAddress)
                    .HasColumnName("M_DetailsAddress")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.MName)
                    .IsRequired()
                    .HasColumnName("M_Name")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.MPhone)
                    .HasColumnName("M_Phone")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.MPicture)
                    .HasColumnName("M_Picture")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.MRegisterDate)
                    .HasColumnName("M_RegisterDate")
                    .HasColumnType("datetime");

                entity.Property(e => e.MState).HasColumnName("M_State");

                entity.Property(e => e.MText)
                    .HasColumnName("M_Text")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.HasOne(d => d.Mu)
                    .WithOne(p => p.Merchant)
                    .HasForeignKey<Merchant>(d => d.MuId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__Merchant__MU_Id__15502E78");
            });

            modelBuilder.Entity<Order>(entity =>
            {
                entity.HasKey(e => e.OId);

                entity.Property(e => e.OId).HasColumnName("O_Id");

                entity.Property(e => e.MuId).HasColumnName("MU_Id");

                entity.Property(e => e.OAddresss)
                    .HasColumnName("O_Addresss")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.OPrice)
                    .HasColumnName("O_Price")
                    .HasColumnType("money");

                entity.Property(e => e.ORegister)
                    .HasColumnName("O_Register")
                    .HasColumnType("datetime");

                entity.Property(e => e.OText)
                    .HasColumnName("O_Text")
                    .HasMaxLength(200)
                    .IsUnicode(false);

                entity.Property(e => e.UId).HasColumnName("U_Id");

                entity.HasOne(d => d.Mu)
                    .WithMany(p => p.Order)
                    .HasForeignKey(d => d.MuId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__Order__MU_Id__239E4DCF");

                entity.HasOne(d => d.U)
                    .WithMany(p => p.Order)
                    .HasForeignKey(d => d.UId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__Order__U_Id__22AA2996");
            });

            modelBuilder.Entity<OrderDetails>(entity =>
            {
                entity.HasKey(e => e.OdId);

                entity.Property(e => e.OdId).HasColumnName("OD_Id");

                entity.Property(e => e.CdId).HasColumnName("CD_Id");

                entity.Property(e => e.OId).HasColumnName("O_Id");

                entity.Property(e => e.OdDic)
                    .HasColumnName("OD_Dic")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.OdSpecification)
                    .HasColumnName("OD_Specification")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.OdSubtotal)
                    .HasColumnName("OD_Subtotal")
                    .HasColumnType("money");

                entity.Property(e => e.OdSum).HasColumnName("OD_Sum");

                entity.HasOne(d => d.O)
                    .WithMany(p => p.OrderDetails)
                    .HasForeignKey(d => d.OId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__OrderDetai__O_Id__267ABA7A");
            });

            modelBuilder.Entity<ShoppingTrolley>(entity =>
            {
                entity.HasKey(e => e.StId);

                entity.Property(e => e.StId).HasColumnName("ST_Id");

                entity.Property(e => e.CdId).HasColumnName("CD_Id");

                entity.Property(e => e.StCommodityDetailsName)
                    .IsRequired()
                    .HasColumnName("ST_CommodityDetailsName")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.StDic)
                    .HasColumnName("ST_Dic")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.StPicture)
                    .HasColumnName("ST_Picture")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.StPrice)
                    .HasColumnName("ST_Price")
                    .HasColumnType("money");

                entity.Property(e => e.StSpecification)
                    .IsRequired()
                    .HasColumnName("ST_Specification")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.StSum).HasColumnName("ST_Sum");

                entity.Property(e => e.UId).HasColumnName("U_Id");

                entity.HasOne(d => d.U)
                    .WithMany(p => p.ShoppingTrolley)
                    .HasForeignKey(d => d.UId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__ShoppingTr__U_Id__1FCDBCEB");
            });

            modelBuilder.Entity<Uaddress>(entity =>
            {
                entity.HasKey(e => e.UaId);

                entity.ToTable("UAddress");

                entity.Property(e => e.UaId).HasColumnName("UA_Id");

                entity.Property(e => e.UId).HasColumnName("U_Id");

                entity.Property(e => e.UaCity)
                    .IsRequired()
                    .HasColumnName("UA_City")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaCityValue)
                    .IsRequired()
                    .HasColumnName("UA_City_Value")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaDetailedAddress)
                    .IsRequired()
                    .HasColumnName("UA_DetailedAddress")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.UaDistrict)
                    .IsRequired()
                    .HasColumnName("UA_District")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaDistrictValue)
                    .IsRequired()
                    .HasColumnName("UA_District_Value")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaName)
                    .IsRequired()
                    .HasColumnName("UA_Name")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaPhone)
                    .IsRequired()
                    .HasColumnName("UA_Phone")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaProvince)
                    .IsRequired()
                    .HasColumnName("UA_Province")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaProvinceValue)
                    .IsRequired()
                    .HasColumnName("UA_Province_Value")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UaState).HasColumnName("UA_State");

                entity.HasOne(d => d.U)
                    .WithMany(p => p.Uaddress)
                    .HasForeignKey(d => d.UId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK__UAddress__U_Id__1273C1CD");
            });

            modelBuilder.Entity<User>(entity =>
            {
                entity.HasKey(e => e.UId);

                entity.Property(e => e.UId).HasColumnName("U_Id");

                entity.Property(e => e.UAccount)
                    .HasColumnName("U_Account")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.UCategory).HasColumnName("U_Category");

                entity.Property(e => e.UGender).HasColumnName("U_Gender");

                entity.Property(e => e.UName)
                    .IsRequired()
                    .HasColumnName("U_Name")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.UPassword)
                    .HasColumnName("U_Password")
                    .HasMaxLength(50)
                    .IsUnicode(false);

                entity.Property(e => e.UPhone)
                    .HasColumnName("U_Phone")
                    .HasMaxLength(20)
                    .IsUnicode(false);

                entity.Property(e => e.UPicture)
                    .HasColumnName("U_Picture")
                    .HasMaxLength(100)
                    .IsUnicode(false);

                entity.Property(e => e.URegisterDate)
                    .HasColumnName("U_RegisterDate")
                    .HasColumnType("datetime");
            });
        }
    }
}
